---
name: Feature request
about: Suggest an idea for GeometricKernels
labels: enhancement
---

<!-- Lines like this are comments and will be invisible -->

# Feature request

<!-- Please give a clear and concise description of your feature proposal! -->

## Motivation

**Is your feature request related to a problem?**
<!-- A clear and concise description of the problem. For example: I'm always frustrated when [...] -->
<!-- Are there relevant issues or other PRs? Please add links -->
<!-- Who will benefit from this feature? -->

## Proposal

**Describe the solution you would like**
<!-- A clear and concise description of what you want to happen. -->

**What alternatives have you considered?**
<!-- A clear and concise description of any alternative solutions or features you've considered. -->

**Are you willing to open a pull request?** (We really appreciate contributions!)

## Additional context

<!-- Add any other context / information about your feature request here. -->